from distutils.core import setup
setup(
  name='django-notifyAll',
  packages=['notifyAll'],
  version='0.1.1',
  description='A lib which you can use for all types of notifications like SMS, Mail, Push.',
  author='Neeraj Dhiman',
  author_email='ndhiman08@gmail.com',
  license='GPL',
  url='https://github.com/inforian/django-notifyAll',
  download_url='https://github.com/inforian/django-notifyAll/archive/0.1.1tar.gz',
  keywords=['notification', 'notify', 'sms', 'email', 'push'],
  classifiers=[],
)